@@ -48,5 +48,5 @@ val verbose : bool
 val warnings : bool
   (** If true, print warnings.  [--no-warnings] sets this to false. *)
 
-val yum_config : string option
-  (** Yum configuration file. *)
+val packager_config : string option
+  (** Package manager configuration file. *)
